@@ -129,7 +129,7 @@ struct _GtkHTMLEditorAPI
 };
 
 /* Creation.  */
-GtkType                    gtk_html_get_type                      (void);
+GType                    gtk_html_get_type                      (void);
 void                       gtk_html_construct                     (GtkHTML                   *html);
 GtkWidget                 *gtk_html_new                           (void);
 void                       gtk_html_set_editor_api                (GtkHTML                   *html,
@@ -208,6 +208,9 @@ void                       gtk_html_set_caret_mode                (GtkHTML
 								   gboolean                   caret_mode);
 gboolean                   gtk_html_get_caret_mode                (const GtkHTML             *html);
 
+void			   gtk_html_set_caret_first_focus_anchor  (GtkHTML		     *html,
+								   const char                *name);
+
 /* Animated Images */
 void                       gtk_html_set_animate                   (GtkHTML                   *html,
 								   gboolean                   animate);
